Get unique MS2 spectra — BAGO 0.0.1 documentation

# Get unique MS2 spectra

getUniqueMS2(d, rtTol=1.0, precsMzTol=0.01, dpTol=0.95)

  Function to get the unique MS2 spectra from a `MSData` object.

  Parameters:

    - d – a `MSData` object. MS data.

    - rtTol – float. Retention time tolerance in minutes.

    - precsMzTol – float. Precursor m/z tolerance in Da.

    - dpTol – float. Dot product tolerance.

  Returns:

    List. A list containing the grouped MS2 spectra.

To use this function:

    # You need a MSData object (d).

    ms2List = getUniqueMS2(d)